@@ -5,7 +5,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '0.001_001';
+our $VERSION = '0.001_002';
 $VERSION = eval $VERSION;   ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 ## no critic (RequirePodAtEnd)
@@ -14,11 +14,11 @@ $VERSION = eval $VERSION;   ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 =head1 NAME
 
-Array:2D - Methods for simple array-of-arrays data structures
+Array::2D - Methods for simple array-of-arrays data structures
 
 =head1 VERSION
 
-This documentation refers to version 0.001_001
+This documentation refers to version 0.001_002
 
 =head2 NOTICE
 
@@ -56,17 +56,20 @@ contains other arrays:
    [ 4, 5, 6 ] ,
  ]
 
-Most of the time, it's good practice to avoid having programs that use
-a module know about the internal construction of an object. However,
-this module is not like that. It exists purely to give methods to a
-standard construction in Perl, and will never change the data structure
-to include anything else. Therefore, it is perfectly reasonable to use
-the normal reference syntax to access items inside the array. A
-construction like C<< $array2d->[0][1] >>  for accessing a single
-element, or C<< @{$array2d} >> to get the list of rows, is perfectly
-acceptable. This module exists because the reference-based 
-implementation of multidimensional arrays in Perl makes it difficult to
-access, for example, a single column, or a two-dimensional slice,
+This module provides methods for using that standard construction.
+
+Most of the time, it's good practice to avoid having programs that
+use a module know about the internal construction of an object.
+However, this module is not like that.  It assumes that the data
+structure I<is> accessible outside the module's code, and may be
+altered by other code.  The module will never change the data
+structure to include anything else. Therefore, it is perfectly
+reasonable to use the normal reference syntax to access items inside
+the array. A construction like C<< $array2d->[0][1] >>  for accessing
+a single element, or C<< @{$array2d} >> to get the list of rows,
+is perfectly appropriate. This module exists because the reference-based
+implementation of multidimensional arrays in Perl makes it difficult
+to access, for example, a single column, or a two-dimensional slice,
 without writing lots of extra code.
 
 Array::2D uses "row" for the first dimension, and "column" or
@@ -120,12 +123,12 @@ array itself.
 
 # core modules
 use Carp;
-use List::Util(qw/any all max min none/);
+use List::Util(qw/max min/);
 use POSIX (qw/floor ceil/);
 use Scalar::Util(qw/blessed reftype/);
 
 # non-core modules
-use List::MoreUtils(qw/natatime/);
+use List::MoreUtils 0.28 (qw/natatime any all none/);
 use Params::Validate(qw/validate ARRAYREF HASHREF/);
 
 ### Test for Ref::Util and if present, use it
@@ -269,7 +272,7 @@ the rows inside the object, use C<clone()>.
 If you think it's possible that the detect-an-AoA-structure could
 give a false positive (you want a new object that might have only one row,
 where each entry in that row is an reference to an unblessed array),
-use C<Array::2D->bless ( [ @your_rows ] )>.
+use C<< Array::2D->bless ( [ @your_rows ] ) >>.
 
 =cut
 
@@ -428,7 +431,7 @@ sub new_down {
 
 =item B<new_to_term_width (...)>
 
-A combination of I<new_down> and I<tabulate_equal_width>.  Takes three named
+A combination of C<new_down()> and C<tabulate_equal_width()>.  Takes three named
 arguments:
 
 =over
@@ -1062,7 +1065,7 @@ sub slice_cols {
     return $return;
 } ## tidy end: sub slice_cols
 
-=item B<slice(I<row_idx_from, col_idx_to, col_idx_from, col_idx_to>)>
+=item B<slice(I<row_index_from, row_index_to, col_index_from, col_index_to>)>
 
 Takes a two-dimensional slice of the array; like cutting a rectangle
 out of the array.
@@ -2117,7 +2120,7 @@ sub hash_of_row_elements {
 
 =head2 TABULATING INTO COLUMNAR OUTPUT
 
-If the C<Unicode::GCString|Unicode::GCString> module can be loaded,
+If the L<Unicode::GCString|Unicode::GCString> module can be loaded,
 its C<columns> method will be used to determine the width of each
 character. This will treat composed accented characters and
 double-width Asian characters correctly.
@@ -2143,7 +2146,7 @@ So, for example,
  # $arrayref = [ 'a    bbb cc' ,
  #               'dddd e   f'
  #             ];
- 
+
 Completely empty columns and rows will be removed.
 
 =item B<tabulate_equal_width(I<separator>)>
@@ -2352,7 +2355,7 @@ sub tsv {
 
 } ## tidy end: sub tsv
 
-=item B<<file(...) >>
+=item B<< file(...) >>
 
 Accepts a file specification and creates a new file at that  location
 containing the data in the 2D array.
@@ -2583,9 +2586,19 @@ CSV, JSON, maybe other file types in C<new_from_file()> and C<file()>.
 
 =head1 SEE ALSO
 
-The L<Data::Table|Data::Table> module on CPAN provides a more conventionally
-opaque object that does many of the same things as this module, and also 
-a lot more.
+Some other modules that have some similarities include:
+
+=over
+
+=item L<Data::Table|Data::Table>
+
+=item L<PDL|PDL>
+
+=item L<Text::Table|Text::Table>
+
+=back
+
+These all appear much more powerful than Array::2D and may better suit your use.
 
 =head1 DEPENDENCIES
 
@@ -2593,7 +2606,7 @@ a lot more.
 
 =item Perl 5.8.1 or higher
 
-=item List::MoreUtils
+=item List::MoreUtils, 0.28 or higher
 
 =item Params::Validate
 
